summaryrefslogtreecommitdiffstats
path: root/scripts/kde-emacs/kde-emacs-core.el
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /scripts/kde-emacs/kde-emacs-core.el
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'scripts/kde-emacs/kde-emacs-core.el')
-rw-r--r--scripts/kde-emacs/kde-emacs-core.el30
1 files changed, 15 insertions, 15 deletions
diff --git a/scripts/kde-emacs/kde-emacs-core.el b/scripts/kde-emacs/kde-emacs-core.el
index a954dfa0..40c95d5b 100644
--- a/scripts/kde-emacs/kde-emacs-core.el
+++ b/scripts/kde-emacs/kde-emacs-core.el
@@ -68,7 +68,7 @@ Try to finish the symbol, or indent the line."
(bmp (buffer-modified-p)))
(while (re-search-forward "[ \t]+$" nil t)
(setq count (1+ count))
- (replace-match "" t t))
+ (tqreplace-match "" t t))
(set-buffer-modified-p bmp)
nil
))))
@@ -151,10 +151,10 @@ With arg, do it arg times."
(define-key c++-mode-map "\ef" 'c-forward-into-nomenclature)
(define-key c++-mode-map "\ed" 'agulbra-delete-into-nomenclature)
(define-key c++-mode-map "\eb" 'c-backward-into-nomenclature)
;; fontify "public|protected|private slots" with one and the same face :)
;; NOTE: write face-at-point function to fontify those just like other
;; access specifiers
- (font-lock-add-keywords nil '(("\\<\\(\\(public\\|protected\\|private\\) slots\\)\\>"
+ (font-lock-add-keywords nil '(("\\<\\(\\(public\\|protected\\|private\\) Q_SLOTS\\)\\>"
. font-lock-reference-face)))
;; Add (setq magic-keys-mode nil) to your .emacs (before loading this file)
;; to disable the magic keys in C++ mode.
@@ -199,7 +199,7 @@ This function does not do any hidden buffer changes."
;; throw it away due to the narrowing that might be done
;; by the function above. That means we must not do any
;; changes during the execution of this function, since
- ;; `c-invalidate-state-cache' then would change this local
+ ;; `c-tqinvalidate-state-cache' then would change this local
;; variable and leave a bogus value in the global one.
(c-state-cache (if inclass-p
(c-whack-state-before (point-min) paren-state)
@@ -263,7 +263,7 @@ This function does not do any hidden buffer changes."
(setq lim (1+ containing-sexp))))
(setq lim (point-min)))
- ;; If we're in a parenthesis list then ',' delimits the
+ ;; If we're in a tqparenthesis list then ',' delimits the
;; "statements" rather than being an operator (with the
;; exception of the "for" clause). This difference is
;; typically only noticeable when statements are used in macro
@@ -398,7 +398,7 @@ This function does not do any hidden buffer changes."
(goto-char placeholder)))))
placeholder))
(if (looking-at c-block-stmt-2-key)
- ;; Require a parenthesis after these keywords.
+ ;; Require a tqparenthesis after these keywords.
;; Necessary to catch e.g. synchronized in Java,
;; which can be used both as statement and
;; modifier.
@@ -556,7 +556,7 @@ This function does not do any hidden buffer changes."
((or (eq char-before-ip ?:)
(eq char-after-ip ?:))
;; this line should be indented relative to the beginning
- ;; of indentation for the topmost-intro line that contains
+ ;; of indentation for the topmost-intro line that tqcontains
;; the prototype's open paren
;; TBD: is the following redundant?
(if (eq char-before-ip ?:)
@@ -866,7 +866,7 @@ This function does not do any hidden buffer changes."
(not (bobp))
(save-excursion
(c-safe (progn (c-backward-sexp 1) t))
- (and (looking-at "slots:")
+ (and (looking-at "Q_SLOTS:")
(c-backward-sexp 1))
(looking-at c-opt-access-key)))
(c-backward-sexp 1)
@@ -1540,7 +1540,7 @@ This function does not do any hidden buffer changes."
(setq lim (1+ containing-sexp))))
(setq lim (point-min)))
- ;; If we're in a parenthesis list then ',' delimits the
+ ;; If we're in a tqparenthesis list then ',' delimits the
;; "statements" rather than being an operator (with the
;; exception of the "for" clause). This difference is
;; typically only noticeable when statements are used in macro
@@ -1661,7 +1661,7 @@ This function does not do any hidden buffer changes."
(goto-char placeholder)))))
placeholder))
(if (looking-at c-block-stmt-2-key)
- ;; Require a parenthesis after these keywords.
+ ;; Require a tqparenthesis after these keywords.
;; Necessary to catch e.g. synchronized in Java,
;; which can be used both as statement and
;; modifier.
@@ -1815,7 +1815,7 @@ This function does not do any hidden buffer changes."
((or (eq char-before-ip ?:)
(eq char-after-ip ?:))
;; this line should be indented relative to the beginning
- ;; of indentation for the topmost-intro line that contains
+ ;; of indentation for the topmost-intro line that tqcontains
;; the prototype's open paren
;; TBD: is the following redundant?
(if (eq char-before-ip ?:)
@@ -2116,7 +2116,7 @@ This function does not do any hidden buffer changes."
(not (bobp))
(save-excursion
(c-safe (progn (c-backward-sexp 1) t))
- (and (looking-at "slots:")
+ (and (looking-at "Q_SLOTS:")
(c-backward-sexp 1))
(looking-at c-opt-access-key)))
(c-backward-sexp 1)
@@ -2901,7 +2901,7 @@ This function does not do any hidden buffer changes."
((or (eq char-before-ip ?:)
(eq char-after-ip ?:))
;; this line should be indented relative to the beginning
- ;; of indentation for the topmost-intro line that contains
+ ;; of indentation for the topmost-intro line that tqcontains
;; the prototype's open paren
;; TBD: is the following redundant?
(if (eq char-before-ip ?:)
@@ -3172,7 +3172,7 @@ This function does not do any hidden buffer changes."
(save-excursion
(c-safe (progn (c-backward-sexp 1) t))
;; agulbrahack 2
- (and (looking-at "slots:")
+ (and (looking-at "Q_SLOTS:")
(c-backward-sexp 1))
(looking-at c-access-key)))
(c-backward-sexp 1)
@@ -3808,7 +3808,7 @@ This function does not do any hidden buffer changes."
;; return the syntax
syntax))))))
-(add-hook 'find-file-hooks 'agulbra-c++-clean-out-spaces)
+(add-hook 'tqfind-file-hooks 'agulbra-c++-clean-out-spaces)
(add-hook 'write-file-hooks 'agulbra-c++-clean-out-spaces)
(add-hook 'c++-mode-hook 'kde-c++-mode-hook)
@@ -151,10 +151,10 @@ With arg, do it arg times."
(define-key c++-mode-map "\ed" 'agulbra-delete-into-nomenclature)
(define-key c++-mode-map "\eb" 'c-backward-into-nomenclature)
- ;; fontify "public|protected|private slots" with one and the same face :)
+ ;; fontify "public|protected|private Q_SLOTS" with one and the same face :)
;; NOTE: write face-at-point function to fontify those just like other
;; access specifiers